/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.action;

import java.awt.event.*;
import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.resource.*;
import edu.stanford.smi.protege.util.*;

/**
 * @author    Simon Ilyushchenko <simonf@cshl.edu>
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class CopyAction extends AllowableAction {

    public CopyAction(String text, Selectable selectable) {
        super(text, Icons.getCopyIcon(), selectable);
    }

    public void actionPerformed(ActionEvent event) {
        if (isAllowed()) {
            WaitCursor cursor = new WaitCursor((JComponent) getSelectable());
            try {
                onCopy();
            } finally {
                cursor.hide();
            }
        }
    }

    public void onCopy() {

        CopyPanel panel = new CopyPanel();
        int dialogResult =
            ModalDialog.showDialog((JComponent) getSelectable(), panel, "Copy", ModalDialog.MODE_OK_CANCEL);

        if (dialogResult == ModalDialog.OPTION_OK) {
            Integer result = panel.getNumberOfCopies();
            if (result != null) {
                int number = result.intValue();
                if (number > 0) {
                    boolean isDeep = panel.getIsDeepCopy();
                    copy(number, isDeep);
                }
            }
        }
    }
    protected void copy(int number, boolean isDeep) {
        Iterator i = getSelection().iterator();
        while (i.hasNext()) {
            Instance inst = (Instance) i.next();
            for (int n = 0; n < number; n++) {
                copy(inst, isDeep);
            }
        }
    }

    protected Instance copy(Instance instance, boolean isDeep) {
        return (Instance) instance.copy(null, null, isDeep);
    }
}
