/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.model.framestore.undo;

import java.util.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.*;

class SetDirectTemplateSlotCommand extends AbstractCommand {
    private Cls cls;
    private Slot slot;
    private Collection values;
    private List oldValues;

    public SetDirectTemplateSlotCommand(FrameStore delegate, Cls cls, Collection values, Slot slot) {
        super(delegate);
        this.cls = cls;
        this.values = values;
        this.slot = slot;
        String description =
            "Set template slot " + getText(slot) + " at class " + getText(cls) + " to values " + getText(values);
        setDescription(description);
    }
    public Object doIt() {
        oldValues = getDelegate().getDirectTemplateSlotValues(cls, slot);
        getDelegate().setDirectTemplateSlotValues(cls, slot, values);
        return null;
    }
    public void undoIt() {
        getDelegate().setDirectTemplateSlotValues(cls, slot, oldValues);
    }
    public void redoIt() {
        getDelegate().setDirectTemplateSlotValues(cls, slot, values);
    }
}