/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2001.  All Rights Reserved.
 *
 * Protege-2000 was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu
 *
 * Contributor(s):
 */

package edu.stanford.smi.protege.test;

import java.io.*;
import java.net.*;
import java.util.*;

import junit.framework.*;

import edu.stanford.smi.protege.model.*;

/**
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class AbstractProjectFactory implements ProjectFactory {

    protected static void checkErrors(Collection c) {
        if (!c.isEmpty()) {
            Iterator i = c.iterator();
            while (i.hasNext()) {
                Object o = i.next();
                System.err.println("Error: " + o.toString());
            }
            System.err.flush();
            Assert.fail();
        }
    }

    private static File getTempDirectory() {
        return AbstractTestCase.getTempDirectory();
    }

    protected static URI getProjectURI() {
        URI projectURI = null;
        try {
            File tmpFile = File.createTempFile("test", ".pprj", getTempDirectory());
            projectURI = tmpFile.toURI();
        } catch (IOException e) {
            Assert.fail(e.getMessage());
        }
        return projectURI;
    }

    public Project saveAndReloadProject(Project project) {
        URI uri = project.getProjectURI();
        if (uri == null) {
            uri = getProjectURI();
            project.setProjectURI(uri);
        }
        Collection errors = new ArrayList();
        int frameCount = project.getKnowledgeBase().getFrameCount();
        project.save(errors);
        checkErrors(errors);
        project.dispose();
        project = Project.loadProjectFromURI(uri, errors);
        checkErrors(errors);
        Assert.assertEquals(frameCount, project.getKnowledgeBase().getFrameCount());
        return project;
    }
}
